baseObjects.ResultSet

|  | ## Cheshire3 Object Model: Class ResultSet

Module baseObjects :: Class ResultSet

## Class ResultSet
source code

Known Subclasses:
  resultSet.RankedResultSet, resultSet.BitmapResultSet

A collection of records, typically created as the result of a search on a database.
Instance Methods

combine(self, session, others, clause)
retrieve(self, session, req)
sort(self, session, req)

Class Variables

expires |
id |
index |
maxWeight |
minWeight |
queryFragment |
queryFreq |
queryPositions |
queryTerm |
relevancy |
termid |
totalOccs |
totalRecs |

Method Details

### combine(self, session, others, clause) | source code

### retrieve(self, session, req) | source code

### sort(self, session, req) | source code

Class Variable Details

    ### expires Value:
        ''

    ### id Value:
        ''

    ### index Value:
        None

    ### maxWeight Value:
        0

    ### minWeight Value:
        0

    ### queryFragment Value:
        None

    ### queryFreq Value:
        0

    ### queryPositions Value:
        []

    ### queryTerm Value:
        ''

    ### relevancy Value:
        0

    ### termid Value:
        -1

    ### totalOccs Value:
        0

    ### totalRecs Value:
        0